@@ -1,5 +1,5 @@
 import requests,re,datetime,json
-def InstaWeb_GetData(self,Link,Private=False):
+def InstaWeb_GetData(Link,Private=False):
     if not Link.endswith("/"):
         str(Link) + "/"
     url = str(Link)+"?__a=1"
@@ -10,7 +10,7 @@ def InstaWeb_GetData(self,Link,Private=False):
     content = json.loads(r.content)
     r.close()
     return content
-def InstaWeb_Download(self, Filename, Data):
+def InstaWeb_Download(Filename, Data):
     content = Data['graphql']['shortcode_media']
     if content['__typename'] == "GraphImage":
         r = requests.get(content['display_url'])
@@ -33,7 +33,7 @@ def InstaWeb_Download(self, Filename, Data):
                 with open(str(index) + "-" + Filename + ".png", "wb") as f:
                     f.write(r.content)
     r.close()
-def InstaWeb_GetUrl(self, Data):
+def InstaWeb_GetUrl(Data):
     content = Data['graphql']['shortcode_media']
     if content['__typename'] == "GraphImage":
         return content['display_url']
@@ -44,7 +44,7 @@ def InstaWeb_GetUrl(self, Data):
         for x in content['edge_sidecar_to_children']['edges']:
             urls.append(x)
         return urls
-def InstaMobile_GetData(self, Link, Private=False):
+def InstaMobile_GetData(Link, Private=False):
     url = str(Link.split("?")[0])
     url += "?__a=1"
     if Private == False:
@@ -54,7 +54,7 @@ def InstaMobile_GetData(self, Link, Private=False):
     content = json.loads(r.content)
     r.close()
     return content
-def InstaMobile_Download(self, Filename, Data):
+def InstaMobile_Download(Filename, Data):
     content = Data['graphql']['shortcode_media']
     if content['__typename'] == "GraphImage":
         r = requests.get(content['display_url'])
@@ -75,7 +75,7 @@ def InstaMobile_Download(self, Filename, Data):
                 with open(Filename + ".png", "wb") as f:
                     f.write(r.content)
     r.close()
-def InstaMobile_GetUrl(self, Data):
+def InstaMobile_GetUrl(Data):
     content = Data['graphql']['shortcode_media']
     if content['__typename'] == "GraphImage":
         return content['display_url']
@@ -86,7 +86,7 @@ def InstaMobile_GetUrl(self, Data):
         for x in content['edge_sidecar_to_children']['edges']:
             urls.append(x)
         return urls
-def SnapChat_GetData(self, Username):
+def SnapChat_GetData(Username):
     rHeaders = {
         "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:81.0) Gecko/20100101 Firefox/81.0",
         "Referer": "http://play.snapchat.com/" + Username + "?upnext=1&loop=true"
@@ -94,19 +94,19 @@ def SnapChat_GetData(self, Username):
     r = requests.get("https://storysharing.snapchat.com/v1/fetch/" + Username, headers=rHeaders)
     content = json.loads(r.content)
     return content
-def SnapChet_Download(self, Filename, Data):
+def SnapChet_Download(Filename, Data):
     content = Data
     for index,x in enumerate(content['story']['snaps'], start=1):
         with open(str(index) + "-" + Filename + ".mp4" if x['media']['type'] == "VIDEO" else ".png", "wb") as f:
             r = requests.get(x['media']['mediaUrl'])
             f.write(r.content)
-def SnapChat_GetUrl(self, Data):
+def SnapChat_GetUrl(Data):
     urls = []
     content = Data
     for url in content['story']['snaps']:
         urls.append(url)
     return urls
-def Twitter_GetData(self, Link):
+def Twitter_GetData(Link):
     code = Link.split("/")[-1]
     rHeaders = {
         "Accept": "*/*",
@@ -125,7 +125,7 @@ def Twitter_GetData(self, Link):
     # print(json.loads(r.content))
     content = json.loads(r.content)
     return [content, code]
-def Twitter_Download(self, Filename, Data):
+def Twitter_Download(Filename, Data):
     for index,x in enumerate(Data[0]['globalObjects']['tweets'][Data[1]]['extended_entities']['media'], start=1):
         if x['type'] == "video":
             for z in x['video_info']['variants']:
@@ -135,7 +135,7 @@ def Twitter_Download(self, Filename, Data):
         elif x['type'] == "photo":
             with open(str(index) + "-" + Filename + ".png", "wb") as f:
                 f.write(requests.get(x['media_url']).content)
-def Twitter_GetUrl(self, Data):
+def Twitter_GetUrl(Data):
     urls = []
     for x in Data[0]['globalObjects']['tweets'][Data[1]]['extended_entities']['media']:
         if x['type'] == "video":
